update_value — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- wizard »

# update_value

A wizard to update a field on a collection of objects

class `camelot.view.wizard.update_value.` `SelectValuePage`(parent, admin, data)

  Page to select a value to update

class `camelot.view.wizard.update_value.` `UpdateValueWizard`(parent=None, selection_getter=None, admin=None)

  This wizard presents the user with a selection of the possible fields to update and a new value. Then this field is changed for all objects in a given collection

  `select_value_page`

    alias of `SelectValuePage`

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- wizard »

Comments
blog comments powered by Disqus